# noo

Easily create new projects.

![Lint](https://github.com/py-noo/noo/actions/workflows/black.yml/badge.svg)

## Installation

```sh
pip install pynoo
```

or install from github

```sh
pip install git+https://github.com/py-noo/noo
```

## Contributing

See [contributing](./.github/CONTRIBUTING.md).

## Basic Usage

```sh
noo clone <name> <ref> - Clone a new project.
noo more <ref> - Modify the current project with a noofile.
```

## Documentation

The project documentation can be found on [our site](https://nooproject.dev).

For additional help you may find it useful to join our [Discord server](https://discord.gg/zbMBkC3849).
